==> kahakai-0.6.1.tar.bz2: kahakai-0.6.1/data/scripts/ruby/events.rb <==
# $Id: events.rb,v 1.7 2003/09/21 00:30:38 pervago Exp $

# Warnings for debugging
def warn s
	puts "*** Warning:  #{s}"
end

def currentScreen
  return Kahakai::WindowManager.Instance().script_current_screen;
end

# Modifier key class used for Events
# * instantiate via Modifier::create
class Modifier
#	private_class_method :new

	attr_reader  :mod, :nmod

	# pre-defined modifier names
	DEFINED = { 
		'MoveResizeMask' => Kahakai::const_get( :MoveResizeMask )
	}
	Kahakai::getXModifiers( currentScreen.display ).each do |comp|
		DEFINED[ comp.first ] = comp.second
	end

	# Creates new Modifier instance
	# * accepts String or Fixnum argument
	# * aliased to Modifier#normalize
	#   for clarity when 'casting'
	def Modifier.create obj
		case obj
			when Modifier
				obj
			when String
				if Modifier::defined? obj
					new Modifier::DEFINED[obj]
				else
					warn "Unknown modifier #{s}"
					new
				end
			when Fixnum
				new obj
			else
				warn "Wrong type for modifier: #{obj} is a #{obj.class}"
		end
	end
	
	class << self
		alias_method :normalize, :create # sometimes you create, sometimes you normalize
	end

	# Check to see if the modifer name is defined
	def Modifier::defined?( modname )
		Modifier::DEFINED.key? modname
	end
	
	def initialize( mod=0, nmod=0 )
		@mod	= mod
		@nmod	= nmod
	end

	# Adds Modifiers
	# * Will accept argument as a Modifier, String, or Fixnum
	def +( other )
		case other
			when Modifier
				Modifier::new( @mod | other.mod, @nmod | other.nmod )
			when String
				self + Modifier::new( Modifier::DEFINED[other] ) if Modifier::defined? other
			when Fixnum
				Modifier::new( @mod | other, @nmod )
			else
				raise "Can't add Modifier and #{other.class} objects"
		end
	end

	# Subtracts Modifiers
	# * Will accept argument as a Modifier, String, or Fixnum
	def -( other )
		self + Modifier::normalize( other ).negate 
	end

    def -@
        negate
    end

	def to_s
		"<Modifier:  mods = #{@mod}, nmods = #{@nmod}>"
	end

	def negate
		Modifier::new @nmod, @mod
	end

end

# Create some common Modifiers
Ctrl   = C = Modifier::create('Control_L')
Alt    = A = Modifier::create('Alt_L')
Shift  = S = Modifier::create('Shift_L')
Super  = W = Modifier::create('Super_L')

if Modifier::defined? 'Mode_switch'
	AltGr = Modifier::create('Mode_switch')
else
	AltGr = Modifier::new
end

class Event
    attr_reader :detail
    
    def initialize( replay=false )
        @replay = replay
        @detail = @mod = @nmod = 0
    end

	# Sets <tt>action</tt> attributes according to this event
	def set action
		action.type		= self.class::EVENT_TYPE
		action.replay	= @replay
		action.detail	= @detail
		action.nmod, action.mod = @nmod, @mod
	end
end

# Base class for events
class KeyMouseEvent < Event
	# Instantiate an event by either of the following methods:
	# * <tt>Event::new( "keyname" )</tt>
	# * <tt>Event::new( modifiers, "keyname" )</tt>
	def initialize( primary, secondary=nil, replay=false )
        super replay

        case primary
        when Modifier, Fixnum
            modifier, name = Modifier::normalize( primary ), secondary
        else # only name is given
            modifier, name = Modifier::new, primary
        end
        
        @detail = identify name        
        @mod, @nmod	= modifier.mod, modifier.nmod
        @replay		= replay
	end
	
	# Further processing ( for keysyms, etc )
	# * to be implemented in subclasses
	def identify name
	end	
end

class ModifierEvent < Event
    def initialize( modifier=nil, replay=false )
        super replay
        
        if modifier 
            modifier = Modifier::normalize(modifier)

            @mod, @nmod = modifier.mod, modifier.nmod
        end
    end
end

class KeyEvent < KeyMouseEvent

	# Identify <tt>key_sym</tt> for a given <tt>key_name</tt>
	def identify key_name
		key_sym = Kahakai::XStringToKeysym key_name
		if key_sym == Kahakai::NoSymbol
			warn "#{key_sym} is not a valid key name"
		else	
            detail = key_sym
		end
	end

	def set action
		# only set if using a valid key_sym
		super if @detail
	end

end

class KeyPress < KeyEvent
	EVENT_TYPE = Kahakai::KeyPress
end

class KeyRelease < KeyEvent
	EVENT_TYPE = Kahakai::KeyRelease
end

class EnterNotify < ModifierEvent
	EVENT_TYPE = Kahakai::EnterNotify
end

class LeaveNotify < ModifierEvent
	EVENT_TYPE = Kahakai::LeaveNotify
end

class MapRequest < ModifierEvent
	EVENT_TYPE = Kahakai::MapRequest
end

class MouseEvent < KeyMouseEvent

	BUTTONS = {
		'anybutton'	=> 0,
		'button1'		=> Kahakai::Button1,
		'button2'		=> Kahakai::Button2,
		'button3'		=> Kahakai::Button3,
		'button4'		=> Kahakai::Button4,
		'button5'		=> Kahakai::Button5
	}

	# Identify <tt>button</tt> for a given <tt>button_name</tt>
	def identify button_name
		if MouseEvent::BUTTONS.key? button_name.downcase
			MouseEvent::BUTTONS[ button_name.downcase ]
		elsif button_name.downcase =~ /^button(\d+)$/
			$1.to_i
		else
			warn "Unknown button:  #{button_name}"
		end
	end
	
	def set(action)
		# only set if using a valid button
		super if @detail
	end
	
end

class ButtonPress < MouseEvent
	EVENT_TYPE = Kahakai::ButtonPress
end

class DoubleClick < MouseEvent
	EVENT_TYPE = Kahakai::DoubleClick
end

class ButtonRelease < MouseEvent
	EVENT_TYPE = Kahakai::ButtonRelease
end

$kahakai	= Kahakai::WindowManager.Instance()
$callbacks = Hash::new

==> kahakai-0.6.2.tar.bz2: kahakai-0.6.2/data/scripts/ruby/events.rb <==
# $Id: events.rb,v 1.9 2004/02/04 21:53:27 brailsmt Exp $

# Warnings for debugging
def warn s
	puts "*** Warning:  #{s}"
end

def currentScreen
  return Kahakai::Kahakai.Instance().script_current_screen;
end

# Modifier key class used for Events
# * instantiate via Modifier::create
class Modifier
#	private_class_method :new

	attr_reader  :mod, :nmod

	# pre-defined modifier names
	DEFINED = { 
		'MoveResizeMask' => Kahakai::const_get( :MoveResizeMask )
	}
	Kahakai::getXModifiers( currentScreen.display ).each do |comp|
		DEFINED[ comp.first ] = comp.second
	end

	# Creates new Modifier instance
	# * accepts String or Fixnum argument
	# * aliased to Modifier#normalize
	#   for clarity when 'casting'
	def Modifier.create obj
		case obj
			when Modifier
				obj
			when String
				if Modifier::defined? obj
					new Modifier::DEFINED[obj]
				else
					warn "Unknown modifier #{obj}"
					new
				end
			when Fixnum
				new obj
			else
				warn "Wrong type for modifier: #{obj} is a #{obj.class}"
		end
	end
	
	class << self
		alias_method :normalize, :create # sometimes you create, sometimes you normalize
	end

	# Check to see if the modifer name is defined
	def Modifier::defined?( modname )
		Modifier::DEFINED.key? modname
	end
	
	def initialize( mod=0, nmod=0 )
		@mod	= mod
		@nmod	= nmod
	end

	# Adds Modifiers
	# * Will accept argument as a Modifier, String, or Fixnum
	def +( other )
		case other
			when Modifier
				Modifier::new( @mod | other.mod, @nmod | other.nmod )
			when String
				self + Modifier::new( Modifier::DEFINED[other] ) if Modifier::defined? other
			when Fixnum
				Modifier::new( @mod | other, @nmod )
			else
				raise "Can't add Modifier and #{other.class} objects"
		end
	end

	# Subtracts Modifiers
	# * Will accept argument as a Modifier, String, or Fixnum
	def -( other )
		self + Modifier::normalize( other ).negate 
	end

    def -@
        negate
    end

	def to_s
		"<Modifier:  mods = #{@mod}, nmods = #{@nmod}>"
	end

	def negate
		Modifier::new @nmod, @mod
	end

end

# Create some common Modifiers
Ctrl   = C = Modifier::create('Control_L')
Alt    = A = Modifier::create('Alt_L')
Shift  = S = Modifier::create('Shift_L')
Super  = W = Modifier::create('Super_L')

if Modifier::defined? 'Mode_switch'
	AltGr = Modifier::create('Mode_switch')
else
	AltGr = Modifier::new
end

class Event
    attr_reader :detail
    
    def initialize( replay=false )
        @replay = replay
        @detail = @mod = @nmod = 0
    end

	# Sets <tt>action</tt> attributes according to this event
	def set action
		action.type		= self.class::EVENT_TYPE
		action.replay	= @replay
		action.detail	= @detail
		action.nmod, action.mod = @nmod, @mod
	end
end

# Base class for events
class KeyMouseEvent < Event
	# Instantiate an event by either of the following methods:
	# * <tt>Event::new( "keyname" )</tt>
	# * <tt>Event::new( modifiers, "keyname" )</tt>
	def initialize( primary, secondary=nil, replay=false )
        super replay

        case primary
        when Modifier, Fixnum
            modifier, name = Modifier::normalize( primary ), secondary
        else # only name is given
            modifier, name = Modifier::new, primary
        end
        
        @detail = identify name        
        @mod, @nmod	= modifier.mod, modifier.nmod
        @replay		= replay
	end
	
	# Further processing ( for keysyms, etc )
	# * to be implemented in subclasses
	def identify name
	end	
end

class ModifierEvent < Event
    def initialize( modifier=nil, replay=false )
        super replay
        
        if modifier 
            modifier = Modifier::normalize(modifier)

            @mod, @nmod = modifier.mod, modifier.nmod
        end
    end
end

class KeyEvent < KeyMouseEvent

	# Identify <tt>key_sym</tt> for a given <tt>key_name</tt>
	def identify key_name
		key_sym = Kahakai::XStringToKeysym key_name
		if key_sym == Kahakai::NoSymbol
			warn "#{key_sym} is not a valid key name"
		else	
            detail = key_sym
		end
	end

	def set action
		# only set if using a valid key_sym
		super if @detail
	end

end

class KeyPress < KeyEvent
	EVENT_TYPE = Kahakai::KeyPress
end

class KeyRelease < KeyEvent
	EVENT_TYPE = Kahakai::KeyRelease
end

class EnterNotify < ModifierEvent
	EVENT_TYPE = Kahakai::EnterNotify
end

class LeaveNotify < ModifierEvent
	EVENT_TYPE = Kahakai::LeaveNotify
end

class MapRequest < ModifierEvent
	EVENT_TYPE = Kahakai::MapRequest
end

class MouseEvent < KeyMouseEvent

	BUTTONS = {
		'anybutton'	=> 0,
		'button1'		=> Kahakai::Button1,
		'button2'		=> Kahakai::Button2,
		'button3'		=> Kahakai::Button3,
		'button4'		=> Kahakai::Button4,
		'button5'		=> Kahakai::Button5
	}

	# Identify <tt>button</tt> for a given <tt>button_name</tt>
	def identify button_name
		if MouseEvent::BUTTONS.key? button_name.downcase
			MouseEvent::BUTTONS[ button_name.downcase ]
		elsif button_name.downcase =~ /^button(\d+)$/
			$1.to_i
		else
			warn "Unknown button:  #{button_name}"
		end
	end
	
	def set(action)
		# only set if using a valid button
		super if @detail
	end
	
end

class ButtonPress < MouseEvent
	EVENT_TYPE = Kahakai::ButtonPress
end

class DoubleClick < MouseEvent
	EVENT_TYPE = Kahakai::DoubleClick
end

class ButtonRelease < MouseEvent
	EVENT_TYPE = Kahakai::ButtonRelease
end

$ka   = Kahakai::Kahakai.Instance()
$callbacks = Hash::new
